@@ -314,47 +314,28 @@ main(int argc, char **argv)
 void
 getdefinitionURL(const char *arg, STRBUF *URL)
 {
-	const char *path;
+	FILE *fp;
 	char *p;
-	STRBUF *sb = NULL;
-	DBOP *dbop = NULL;
 	SPLIT ptable;
 	int status = -1;
+	STRBUF *sb = strbuf_open(0);
 	const char *htmldir = locate_HTMLdir();
+	const char *path = makepath(htmldir, "MAP", NULL);
 
-	path = makepath(htmldir, "MAP.db", NULL);
-	if (test("f", path))
-		dbop = dbop_open(path, 0, 0, 0);
-	if (!dbop) {
-		path = makepath(htmldir, "MAP", NULL);
-		if (!test("f", path))
-			die("'%s' not found. Please reconstruct hypertext using the latest htags(1).", path);
-		dbop = dbop_open(path, 0, 0, 0);
-	}
-	if (dbop) {
-		if ((p = (char *)dbop_get(dbop, arg)) != NULL) {
-			if (split(p, 2, &ptable) != 2)
-				die("illegal format.");
+	if (!test("f", path))
+		die("'%s' not found. Please reconstruct hypertext using the latest htags(1).", path);
+	fp = fopen(path, "r");
+	if (!fp)
+		die("cannot open '%s'.", path);
+	while ((p = strbuf_fgets(sb, fp, STRBUF_NOCRLF)) != NULL) {
+		if (split(p, 2, &ptable) != 2)
+			die("illegal format.");
+		if (!strcmp(arg, ptable.part[0].start)) {
 			status = 0;
-		}
-		dbop_close(dbop);
-	} else {
-		FILE *fp;
-
-		sb = strbuf_open(0);
-		fp = fopen(path, "r");
-		if (fp) {
-			while ((p = strbuf_fgets(sb, fp, STRBUF_NOCRLF)) != NULL) {
-				if (split(p, 2, &ptable) != 2)
-					die("illegal format.");
-				if (!strcmp(arg, ptable.part[0].start)) {
-					status = 0;
-					break;
-				}
-			}
-			fclose(fp);
+			break;
 		}
 	}
+	fclose(fp);
 	if (status == -1)
 		die("definition %s not found.", arg);
 	strbuf_reset(URL);
@@ -363,8 +344,7 @@ getdefinitionURL(const char *arg, STRBUF *URL)
 	 */
 	makefileurl(makepath(htmldir, ptable.part[1].start, NULL), 0, URL);
 	recover(&ptable);
-	if (sb != NULL)
-		strbuf_close(sb);
+	strbuf_close(sb);
 }
 /*
  * getURL: get URL of the specified file.
@@ -376,21 +356,13 @@ void
 getURL(const char *file, STRBUF *URL)
 {
 	char *p;
-	char rootdir[MAXPATHLEN+1];
 	char buf[MAXPATHLEN+1];
 	STRBUF *sb = strbuf_open(0);
 	const char *htmldir = locate_HTMLdir();
 
-        /*
-         * rootdir always ends with '/'.
-         */
-        if (!strcmp(root, "/"))
-                strlimcpy(rootdir, root, sizeof(rootdir));
-        else
-                snprintf(rootdir, sizeof(rootdir), "%s/", root);
 	if (!test("f", file) && !test("d", file))
 		die("path '%s' not found.", file);
-	p = normalize(file, rootdir, cwd, buf, sizeof(buf));
+	p = normalize(file, get_root_with_slash(), cwd, buf, sizeof(buf));
 	if (convertpath(dbpath, htmldir, p, sb) == 0)
 		makefileurl(strbuf_value(sb), linenumber, URL);
 	else
