@@ -119,12 +119,11 @@ int symbol;				/* --symbol(-s) option          */
 int suggest;				/* --suggest option		*/
 int statistics = STATISTICS_STYLE_NONE;	/* --statistics option		*/
 
-int copy_files;				/* 1: copy tag files		*/
 int no_order_list;			/* 1: doesn't use order list	*/
 int other_files;			/* 1: list other files		*/
 int enable_grep = 1;			/* 1: enable grep		*/
 int enable_idutils;			/* 1: enable idutils		*/
-int enable_xhtml;			/* 1: enable XHTML		*/
+int enable_xhtml = 1;			/* 1: enable XHTML		*/
 
 const char *action_value;
 const char *id_value;
@@ -278,6 +277,7 @@ static struct option const long_options[] = {
         {"debug", no_argument, &debug, 1},
         {"disable-grep", no_argument, &enable_grep, 0},
         {"full-path", no_argument, &full_path, 1},
+        {"html", no_argument, &enable_xhtml, 0},
         {"nocgi", no_argument, &cgi, 0},
         {"no-map-file", no_argument, &map_file, 0},
         {"show-position", no_argument, &show_position, 1},
@@ -375,10 +375,19 @@ static void
 make_directory_in_distpath(const char *name)
 {
 	const char *path = makepath(distpath, name, NULL);
+	FILE *op;
 
 	if (!test("d", path))
 		if (mkdir(path, 0775))
 			die("cannot make directory '%s'.", path);
+	/*
+	 * Not to publish the directory list.
+	 */
+	op = fopen(makepath(path, "index.html", NULL), "w");
+	fputs(html_begin, op);
+	fputs(html_end, op);
+	fputc('\n', op);
+	fclose(op);
 }
 /*
  * generate_file: generate file with replacing macro.
@@ -800,16 +809,33 @@ makehtaccess(const char *file)
 	fputs_nl("#", op);
 	fputs_nl("# Skeleton file for .htaccess -- This file was generated by htags(1).", op);
 	fputs_nl("#", op);
-	fputs_nl("# Htags have made gzipped hypertext because you specified -c option.", op);
-	fputs_nl("# If your browser doesn't decompress gzipped hypertext, you will need to", op);
-	fputs_nl("# setup your http server to treat this hypertext as gzipped files first.", op);
-	fputs_nl("# There are many way to do it, but one of the method is to put .htaccess", op);
-	fputs_nl("# file in 'HTML' directory.", op);
+	fputs_nl("# To make this file effective, undermentioned description is necessary", op);
+	fputs_nl("# in your system's configuration file.", op);
 	fputs_nl("#", op);
-	fputs_nl("# Please rewrite '/cgi-bin/ghtml.cgi' to the true value in your web site.", op);
+	fputs_nl("# [/usr/local/apache/conf/http.conf]", op);
+	fputs_nl("# +-------------------------------------", op);
+	fputs_nl("# |...", op);
+	fputs_nl("# |AllowOverride Options FileInfo", op);
 	fputs_nl("#", op);
-	fprintf(op, "AddHandler htags-gzipped-html %s\n", gzipped_suffix);
-	fputs_nl("Action htags-gzipped-html /cgi-bin/ghtml.cgi", op);
+	fputs_nl("# Htags was invoked with the -f, -c or -D option.", op);
+	fprintf(op, "# You should start HTTP server so that %s/cgi-bin/*.cgi is executed", cgidir);
+	fputs_nl("# as a CGI script.", op);
+	fputs_nl("#", op);
+	fputs_nl("Options +ExecCGI", op);
+	fputs_nl("AddHandler cgi-script .cgi", op);
+	if (cflag) {
+		fputs_nl("#", op);
+		fputs_nl("# Htags have made gzipped html files because you specified the -c option.", op);
+		fputs_nl("# If your browser doesn't decompress gzipped files, you should start", op);
+		fputs_nl("# HTTP server so that they are decompressed.", op);
+		fputs_nl("#", op);
+		fputs_nl("# Please rewrite appropriately the string '/cgi-bin/ghtml.cgi' below, or", op);
+		fputs_nl("# copy the file 'cgi-bin/ghtml.cgi' itself to the system's CGI directory.", op);
+		fputs_nl("#", op);
+		fprintf(op, "AddHandler htags-gzipped-html %s\n", gzipped_suffix);
+		fputs_nl("Action htags-gzipped-html /cgi-bin/ghtml.cgi", op);
+		fputs_nl("#                         ==================", op);
+	}
 	fclose(op);
 }
 /*
@@ -1170,8 +1196,6 @@ configuration(int argc, char *const *argv)
 		table_flist = 1;
 	if (getconfb("no_order_list"))
 		no_order_list = 1;
-	if (getconfb("copy_files"))
-		copy_files = 1;
 	if (getconfb("no_map_file"))
 		map_file = 0;
 	strbuf_reset(sb);
@@ -1656,13 +1680,6 @@ main(int argc, char **argv)
 	 */
 	if (enable_xhtml)
 		setup_xhtml();
-	/*
-	 * If copy_files is true then htags copy tag files instead of linking.
-	 * Since Windows 32 environment doesn't have link system call
-	 * we set copy_files true.
-	 */
-	if (w32)
-		copy_files = 1;
         if (show_version)
                 version(av, vflag);
         if (show_help)
@@ -1689,7 +1706,7 @@ main(int argc, char **argv)
 	/*
 	 * get dbpath.
 	 */
-	setupdbpath(vflag);			/* for parsers */
+	setupdbpath(0);				/* for parsers */
 	if (!getcwd(cwdpath, sizeof(cwdpath)))
 		die("cannot get current directory.");
 	if (arg_dbpath[0])
@@ -1841,6 +1858,8 @@ main(int argc, char **argv)
 	/*
 	 * (#) check if GTAGS, GRTAGS is the latest.
 	 */
+	if (get_dbpath())
+		message(" Using %s/GTAGS", get_dbpath());
 	if (!w32) {
 		/* UNDER CONSTRUCTION */
 	}
@@ -1869,12 +1888,22 @@ main(int argc, char **argv)
 	/*
 	 * (1) make CGI program
 	 */
-	if (cgi && (fflag || dynamic)) {
+	if (cgi && (fflag || cflag || dynamic)) {
+		message("[%s] (1) making CGI program ...", now());
 		if (cgidir) {
-			message("[%s] (1) making CGI program ...", now());
-			makeprogram(cgidir, "global.cgi");
-			if (chmod(makepath(cgidir, "global.cgi", NULL), 0755) < 0)
-				die("cannot chmod CGI program.");
+			if (fflag || dynamic) {
+				makeprogram(cgidir, "global.cgi");
+				if (chmod(makepath(cgidir, "global.cgi", NULL), 0755) < 0)
+					die("cannot chmod CGI program.");
+			}
+			if (cflag) {
+				makeghtml(cgidir, "ghtml.cgi");
+				if (chmod(makepath(cgidir, "ghtml.cgi", NULL), 0755) < 0)
+					die("cannot chmod unzip script.");
+			}
+			makehtaccess(".htaccess");
+			if (chmod(makepath(distpath, ".htaccess", NULL), 0644) < 0)
+				die("cannot chmod .htaccess skeleton.");
 		}
 		/*
 		 * Always make bless.sh.
@@ -1886,16 +1915,6 @@ main(int argc, char **argv)
 	} else {
 		message("[%s] (1) making CGI program ...(skipped)", now());
 	}
-	if (cgi && cflag) {
-		makehtaccess(".htaccess");
-		if (chmod(makepath(distpath, ".htaccess", NULL), 0644) < 0)
-			die("cannot chmod .htaccess skeleton.");
-		if (cgidir) {
-			makeghtml(cgidir, "ghtml.cgi");
-			if (chmod(makepath(cgidir, "ghtml.cgi", NULL), 0644) < 0)
-				die("cannot chmod unzip script.");
-		}
-	}
 	/*
 	 * (2) make help file
 	 */
@@ -2011,22 +2030,15 @@ main(int argc, char **argv)
 	}
 	if (vflag && cgi && (cflag || fflag || dynamic)) {
 		message("\n[Information]\n");
+		if (fflag || cflag || dynamic) {
+			message(" o Htags was invoked with the -f, -c or -D option. You should start HTTP");
+			message("   server so that cgi-bin/*.cgi is executed as a CGI script.");
+		}
 		if (cflag) {
-			message(" Your system may need to be setup to decompress *.%s files.", gzipped_suffix);
-			message(" This can be done by having your browser compiled with the relevant");
-			message(" options, or by configuring your http server to treat these as");
-			message(" gzipped files. (Please see 'HTML/.htaccess')\n");
-		}
-		if (fflag || dynamic) {
-			const char *format = " You need to setup http server so that %s is executed as a CGI script.";
-
-			if (*action == '/') {
-				message(format, makepath("DOCUMENT_ROOT", action, NULL));
-				message(" (DOCUMENT_ROOT means WWW server's data root.)");
-			} else {
-				message(format, makepath("HTML", action, NULL));
-			}
+			message(" o Htags was invoked with the -c option. You should start HTTP server to");
+			message("   decompress *.%s files.", gzipped_suffix);
 		}
+ 		message(" If you are using Apache, 'HTML/.htaccess' might be helpful for you.\n");
 		message(" Good luck!\n");
 	}
 	if (Iflag) {
