@@ -4,19 +4,18 @@
  *
  * This file is part of GNU GLOBAL.
  *
- * GNU GLOBAL is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * GNU GLOBAL is distributed in the hope that it will be useful,
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef _HTAGS_H_
 #define _HTAGS_H_
@@ -62,7 +61,6 @@ extern char dbpath[MAXPATHLEN];
 extern char distpath[MAXPATHLEN];
 extern char gtagsconf[MAXPATHLEN];
 
-extern char sort_path[MAXFILLEN];
 extern char gtags_path[MAXFILLEN];
 extern char global_path[MAXFILLEN];
 extern int gtags_exist[GTAGLIM];
@@ -89,7 +87,6 @@ extern int dynamic;
 extern int symbol;
 extern int statistics;
 
-extern int no_map_file;
 extern int no_order_list;
 extern int other_files;
 extern int enable_grep;
@@ -101,6 +98,7 @@ extern const char *id_value;
 extern const char *cgidir;
 extern const char *main_func;
 extern const char *cvsweb_url;
+extern int use_cvs_module;
 extern const char *cvsweb_cvsroot;
 extern const char *gtagslabel;
 extern const char *title;
@@ -110,6 +108,7 @@ extern const char *insert_footer;
 
 extern const char *title_define_index;
 extern const char *title_file_index;
+extern const char *title_call_tree;
 extern const char *title_included_from;
 
 extern const char *anchor_label[];
