@@ -286,7 +286,7 @@ openconf(void)
 		fclose(fp);
 	}
 	/*
-	 * make up lacked variables.
+	 * make up required variables.
 	 */
 	sb = strbuf_open(0);
 	strbuf_puts(sb, confline);
@@ -297,7 +297,7 @@ openconf(void)
 		const char *langmap = NULL;
 
 		/*
-		 * Variable 'suffixes' is obsoleted. But it is generated
+		 * Variable 'suffixes' is obsolete. But it is generated
 		 * internally from the value of variable 'langmap'.
 		 */
 		if (getconfs("langmap", tmp))
@@ -312,36 +312,6 @@ openconf(void)
 		strbuf_puts(sb, ":skip=");
 		strbuf_puts(sb, DEFAULTSKIP);
 	}
-	/*
-	 * GTAGS, GRTAGS and GSYMS have no default values but non of them
-	 * specified then use default values.
-	 * (Otherwise, nothing to do for gtags.)
-	 */
-	if (!getconfs("GTAGS", NULL) && !getconfs("GRTAGS", NULL) && !getconfs("GSYMS", NULL)) {
-		const char *path;
-
-		/*
-		 * usable search in BINDIR at first.
-		 */
-#if defined(_WIN32)
-		path = "gtags-parser.exe";
-#elif defined(__DJGPP__)
-		path = usable("gtags-parser") ? "gtags-parser.exe" : "gtags-~1.exe";
-#else
-		path = usable("gtags-parser");
-		if (!path)
-			path = "gtags-parser";
-#endif /* _WIN32 */
-		strbuf_puts(sb, ":GTAGS=");
-		strbuf_puts(sb, path);
-		strbuf_puts(sb, " %s");
-		strbuf_puts(sb, ":GRTAGS=");
-		strbuf_puts(sb, path);
-		strbuf_puts(sb, " -r %s");
-		strbuf_puts(sb, ":GSYMS=");
-		strbuf_puts(sb, path);
-		strbuf_puts(sb, " -s %s");
-	}
 	strbuf_unputc(sb, ':');
 	strbuf_putc(sb, ':');
 	confline = check_strdup(strbuf_value(sb));
@@ -417,7 +387,22 @@ getconfs(const char *name, STRBUF *sb)
 			strbuf_puts(sb, BINDIR);
 			exist = 1;
 		} else if (!strcmp(name, "datadir")) {
+#if defined(_WIN32) && !defined(__CYGWIN__)
+			/*
+			 * Test if this directory exists, and if not, take the
+			 * directory relative to the binary.
+			 */
+			if (test("d", DATADIR))
+				strbuf_puts(sb, DATADIR);
+			else {
+				const char *name = strrchr(_pgmptr, '\\');
+				if (name)
+					strbuf_nputs(sb, _pgmptr, name+1 - _pgmptr);
+				strbuf_puts(sb, "..\\share");
+			}
+#else
 			strbuf_puts(sb, DATADIR);
+#endif
 			exist = 1;
 		}
 	}
